PELICAN_METADATA = [
    'title',
    'date',
    'modified',
    'tags',
    'keywords',
    'category',
    'slug',
    'author',
    'authors',
    'summary',
    'lang',
    'translation',
    'status',
    'template',
    'save_as',
    'url'
]